@@ -28,7 +28,7 @@ class Post(object):
         self.thumb_url = json['thumb_url']
         self.title = json['title']
         self.url = json['url']
-        self.voted = json['voted']
+        self.voted = json.get('voted')
         self.json = json
     def vote(self, v=1):
         if not v in [-1, 0, 1]: raise ValueError("Vote must be -1, 0, or 1")
@@ -184,21 +184,21 @@ class RuqqusAPI(object):
         return self.session.get(f"https://ruqqus.com/giphy?searchTerm={searchTerm}&limit={limit}").json()
     
     def me(self):
-        return self.session.get("https://ruqqus.com/me").url
+        return self.user(self.session.get("https://ruqqus.com/me").url.split("@")[1])
 
     def random_post(self):
-        return self.session.get("https://ruqqus.com/random/post").url
+        return self.post(self.session.get("https://ruqqus.com/random/post").url.split("/")[-2])
     
     def random_guild(self):
-        return self.session.get("https://ruqqus.com/random/guild").url
+        return self.guild(self.session.get("https://ruqqus.com/random/guild").url.split("+")[1])
     
     def random_user(self):
-        return self.session.get("https://ruqqus.com/random/user").url
+        return self.user(self.session.get("https://ruqqus.com/random/user").url.split("@")[1])
 
     def feeds_public(self, sort="hot"):
         r = self.session.get("https://ruqqus.com/feeds/" + sort)
         try:
-            return atoma.parse_atom_bytes(r.content)
+            return [self.post(i.id_.split('/')[-2]) for i in atoma.parse_atom_bytes(r.content).entries]
         except atoma.exceptions.FeedXMLError:
             return r
 
